searchData={"items":[{"type":"module","title":"LiveStreamAsync","doc":"Extends Phoenix LiveView with `stream_async/4` macro.\n\n   Similar to existing `assign_async/4`, but for streams.\n\n# Installation\n\n   The package can be installed by adding `live_stream_async` to your list of dependencies in `mix.exs`:\n\n# Async streams\n\n   Streams in LiveView allow working with large collections without keeping them on the server. In case you want to work with `streams` assigns asynchronously you may need to resort to low level control functions.\n\n   This library provides a convenient macro `stream_async/4` that auto-generates all the necessary boilerplate behind the scenes and injects it into your LiveView module.\n\n# Usage","ref":"LiveStreamAsync.html"},{"type":"module","title":"Extending Live View - LiveStreamAsync","doc":"Extend your live view module with `use LiveStreamAsync` and you can leverage the `stream_async/4` macro:\n\n   ```elixir\n   use MyAppWeb, :live_view\n   use LiveStreamAsync\n\n   def mount(%{\"location\" => location}, _, socket) do\n   {:ok,\n   socket\n   |> stream_configure(:hotels, dom_id: &\"hotel-#{&1.id}\")\n   |> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n   }\n   end\n   ```","ref":"LiveStreamAsync.html#module-extending-live-view"},{"type":"module","title":"Accessing the result - LiveStreamAsync","doc":"The `<.async_result ...>` component is designed to work with the `%Phoenix.LiveView.AsyncResult{}` structs. The struct is passed via \"`assign={}`\" attribute of the component. The component's inner block receives the `@streams` assign key through `:let={}` attribute.\n\n   Example:\n\n   ```elixir\n     def render(assigns) do\n       ~H\"\"\"\n       <.async_result :let={stream_key} assign={@hotels}>\n       <:loading>Loading hotels...</:loading>\n       <:failed :let={_failure}>There was an error loading the hotels. Please try again later.</:failed>\n          \n            \n           <%= hotel.name %>\n            \n          \n       </.async_result>\n     \"\"\"\n     end\n   ```\n\n   **Note**: in the example above just replace \"@hotels\" with the id of your stream.\n\n# New asynchronous operations in LiveView v.20\n\n   New release of [LiveView library - v 0.20](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html) - introduced built-in functions for [asynchronous work](https://hexdocs.pm/phoenix_live_view/0.20.14/Phoenix.LiveView.html#module-async-operations). It's a perfect solution to deliver a snappy user experience by delegating some time-consuming tasks (ex. fetching from external services) to background jobs without blocking the UI or event handlers. New operations include:\n\n   - `assign_async/4`: a straight forward way to load the results asynchronously into socket assigns.\n   - `start_async/3`: allows lower level control of asynchronous operations with `handle_async` callbacks.\n   - `<.async_result ...>` - function component to handle the asynchronous operation state on the UI side (for success, loading and errors).","ref":"LiveStreamAsync.html#module-accessing-the-result"},{"type":"macro","title":"LiveStreamAsync.stream_async/4","doc":"Assigns stream keys asynchronously.\n\nWraps your function in a task linked to the caller, errors are wrapped. The key passed to `stream_async/4` will be assigned to an `Phoenix.LiveView.AsyncResult` struct holding the status of the operation and the result - key to the streams assign (socket.assigns.streams) - when the function completes.\n\nThe task is only started when the socket is connected.","ref":"LiveStreamAsync.html#stream_async/4"},{"type":"macro","title":"Options - LiveStreamAsync.stream_async/4","doc":"* `:supervisor` - allows you to specify a `Task.Supervisor` to supervise the task.\n* from `Phoenix.LiveView.stream/4` function:\n  * `:at` - the index to insert or update the items in the\n      collection on the client.\n  * `:reset` - the boolean to reset the stream on the client or not. Defaults\n    to `false`.\n  * `:limit` - the optional positive or negative number of results to limit\n    on the UI on the client.","ref":"LiveStreamAsync.html#stream_async/4-options"},{"type":"macro","title":"Example - LiveStreamAsync.stream_async/4","doc":"```elixir\n  use MyAppWeb, :live_view\n  use LiveStreamAsync\n\n  def mount(%{\"location\" => location}, _, socket) do\n  {:ok,\n  socket\n  |> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n  }\n  end\n  ```","ref":"LiveStreamAsync.html#stream_async/4-example"},{"type":"extras","title":"LiveStreamAsync","doc":"# LiveStreamAsync\n\nExtends Phoenix LiveView with `stream_async/4` macro.\n\nSimilar to existing `assign_async/4`, but for streams.","ref":"readme.html"},{"type":"extras","title":"Installation - LiveStreamAsync","doc":"The package can be installed by adding `live_stream_async` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_stream_async, \"~> 0.1.0\", runtime: false}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Async streams - LiveStreamAsync","doc":"Streams in LiveView allow working with large collections without keeping them on the server. In case you want to work with `streams` assigns asynchronously you may need to resort to low level control functions.\n\nThis library provides a convenient macro `stream_async/4` that auto-generates all the necessary boilerplate behind the scenes and injects it into your LiveView module.","ref":"readme.html#async-streams"},{"type":"extras","title":"Usage - LiveStreamAsync","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Extending Live View - LiveStreamAsync","doc":"Extend your live view module with `use LiveStreamAsync` and you can leverage the `stream_async/4` macro:\n\n```elixir\nuse MyAppWeb, :live_view\nuse LiveStreamAsync\n\ndef mount(%{\"location\" => location}, _, socket) do\n{:ok,\nsocket\n|> stream_configure(:hotels, dom_id: &\"hotel-#{&1.id}\")\n|> stream_async(:hotels, fn -> Hotels.fetch!(location) end, reset: true)\n}\nend\n```","ref":"readme.html#extending-live-view"},{"type":"extras","title":"Accessing the result - LiveStreamAsync","doc":"The `<.async_result ...>` component is designed to work with the `%Phoenix.LiveView.AsyncResult{}` structs. The struct is passed via \"`assign={}`\" attribute of the component. The component's inner block receives the `@streams` assign key through `:let={}` attribute.\n\nExample:\n\n```elixir\n  def render(assigns) do\n    ~H\"\"\"\n    <.async_result :let={stream_key} assign={@hotels}>\n    <:loading>Loading hotels...</:loading>\n    <:failed :let={_failure}>There was an error loading the hotels. Please try again later.</:failed>\n       \n         \n        <%= hotel.name %>\n         \n       \n    </.async_result>\n  \"\"\"\n  end\n```\n\n**Note**: in the example above just replace \"@hotels\" with the id of your stream.","ref":"readme.html#accessing-the-result"},{"type":"extras","title":"New asynchronous operations in LiveView v.20 - LiveStreamAsync","doc":"New release of [LiveView library - v 0.20](https://hexdocs.pm/phoenix_live_view/Phoenix.LiveView.html) - introduced built-in functions for [asynchronous work](https://hexdocs.pm/phoenix_live_view/0.20.14/Phoenix.LiveView.html#module-async-operations). It's a perfect solution to deliver a snappy user experience by delegating some time-consuming tasks (ex. fetching from external services) to background jobs without blocking the UI or event handlers. New operations include:\n\n- `assign_async/4`: a straight forward way to load the results asynchronously into socket assigns.\n- `start_async/3`: allows lower level control of asynchronous operations with `handle_async` callbacks.\n- `<.async_result ...>` - function component to handle the asynchronous operation state on the UI side (for success, loading and errors).","ref":"readme.html#new-asynchronous-operations-in-liveview-v-20"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}